# Copyright (c) 2010-2020 Andrew Dalke Scientific, AB (Sweden)
# All Rights Reserved.

## LICENSE ##

# This file contains proprietary and unpublished source code.
#
# You may use and modify this software ONLY under the terms of the
# License agreement you or your organization made with Andrew Dalke
# Scientific AB.
#
# If no other agreeement exists then you may use chemfp under the
# terms of the Chemfp Base License Agreement v1.0 or later.
# See http://chemfp.com/licenses/ for details.
#
# Unless required by applicable law or agreed to in writing, this
# software is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR
# CONDITIONS OF ANY KIND, either express or implied.  See the License
# agreement for the specific language governing permissions and
# limitations under the License.

## /LICENSE ##

def _check_toolkit_or_exit(progname, toolkit_name, toolkit_import):
    try:
        __import__(toolkit_import)
    except ImportError as err:
        if "Unable to use Python 2 with OpenEye Python Toolkits built for Python 3" == str(err):
            raise SystemExit("Cannot run %s: %s" % (progname, err))
        raise SystemExit("Cannot run %s: It appears that %s is not installed: %s" % (
            progname, toolkit_name, err))

def run_ob2fps():
    _check_toolkit_or_exit("ob2fps", "Open Babel", "openbabel")
    from .ob2fps import run
    run()

def run_oe2fps():
    _check_toolkit_or_exit("oe2fps", "OEChem", "openeye.oechem")
    from ..openeye_toolkit import is_licensed
    if not is_licensed():
        raise SystemExit("Cannot run oe2fps: OEChem is available but the license is not valid.")
    from openeye.oegraphsim import OEGraphSimIsLicensed
    if not OEGraphSimIsLicensed():
        raise SystemExit("Cannot run oe2fps: OEChem is available and licensed but the OEGraphSim license is not valid.")
        
    from .oe2fps import run
    run()

def run_rdkit2fps():
    _check_toolkit_or_exit("rdkit2fps", "RDKit", "rdkit.Chem")

    from .rdkit2fps import run
    run()
